import io

class ECDHPrivateKeyBlob:
	def __init__(self):
		self.magic = None
		self.length = None
		self.x = None
		self.y = None
		self.privateexp = None

	@staticmethod
	def from_bytes(data):
		return ECDHPrivateKeyBlob.from_buffer(io.BytesIO(data))
	
	@staticmethod
	def from_buffer(buff):
		pk = ECDHPrivateKeyBlob()
		pk.magic = int.from_bytes(buff.read(4), byteorder='little', signed=False)
		pk.length = int.from_bytes(buff.read(4), byteorder='little', signed=False)
		pk.x = int.from_bytes(buff.read(pk.length), byteorder='little', signed=False)
		pk.y = int.from_bytes(buff.read(pk.length), byteorder='little', signed=False)
		pk.privateexp = int.from_bytes(buff.read(pk.length), byteorder='little', signed=False)
		return pk

	def __str__(self):
		t = ''
		for k in self.__dict__:
			t += '%s: %s\r\n' % (k, self.__dict__[k])
		return t


from setuptools import setup, find_packages
import re

VERSIONFILE="winacl/_version.py"
verstrline = open(VERSIONFILE, "rt").read()
VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
mo = re.search(VSRE, verstrline, re.M)
if mo:
    verstr = mo.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))

setup(
	# Application name:
	name="winacl",

	# Version number (initial):
	version=verstr,

	# Application author details:
	author="Tamas Jos",
	author_email="info@skelsecprojects.com",

	# Packages
	packages=find_packages(),

	# Include additional files into the package
	include_package_data=True,


	# Details
	url="https://github.com/skelsec/winacl",

	zip_safe=True,
	#
	# license="LICENSE.txt",
	description="ACL/ACE/Security Descriptor manipulation library in pure Python",

	# long_description=open("README.txt").read(),
	python_requires='>=3.6',
	classifiers=(
		"Programming Language :: Python :: 3.6",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	),
	install_requires=[
		'cryptography>=38.0.1',
	],

	#entry_points={
	#	'console_scripts': [
	#		'ccacheedit = winacl.examples.<file_name>:main',
	#	],
	#}
)